/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.reporters.pdd;

/**
 * One puzzle.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Puzzle.java 1140 2011-04-04 16:37:58Z yegor256@yahoo.com $
 * @see PDDReporter#report(Model, File)
 */
interface Puzzle {

    /**
     * Get subject of the puzzle.
     * @return The subject
     */
    String getSubject();

    /**
     * Get body of the puzzle.
     * @return The body
     */
    String getBody();

    /**
     * File name, which this puzzle is attached to.
     * @return The file name (relative)
     */
    String getFile();

    /**
     * Get SCM revision ID/name.
     * @return The revision ID/name
     */
    String getRevision();

    /**
     * Get lines.
     * @return The lines interval
     */
    String getLines();

    /**
     * Calculate and return hash code.
     * @return The hash as string
     */
    String getHash();

    /**
     * Get estimate of the puzzle in minutes.
     * @return The estimate, in minutes
     */
    Integer getEstimate();

    /**
     * Get name of the issue, which this puzzle is attached to.
     * @return The name
     */
    String getIssueName();

}
